#! /bin/bash
# The top line might need to be changed if your bash executable is located in another directory.


BBCONFFILE=/etc/bashburnrc
BBROOTDIR=$(dirname $0)/
BBINSTDIR=$(pwd)

overwrite_selection()
{
while true; do
	echo -n "|> "
	read choice
	if [[ "$choice" = "n" ]]; then
		echo
		echo -e "\033[1;31mNot\033[1;0m overwriting config file."
		echo
		echo "Installation finished. Now start BashBurn with the"
		echo -e "command \033[1;36mbashburn\033[1;0m, and remember to"
		echo "configure it before trying to use it."
		echo
		exit
	else
		break
	fi
done
}

install_files()
{
	echo; echo -n "Installing files..."
	# Does the path already exist
	if [[ ! -e "${BBINSTALL_PATH}" ]]; then 
		mkdir ${BBINSTALL_PATH}
	fi
	cp -Rfp ${BBROOTDIR}BashBurn.sh \
		${BBROOTDIR}burning \
		${BBROOTDIR}config \
		${BBROOTDIR}convert \
		${BBROOTDIR}lang \
		${BBROOTDIR}menus \
		${BBROOTDIR}misc \
		${BBROOTDIR}HOWTO \
		${BBINSTALL_PATH}
	echo -e "\033[1;32m[DONE]\033[1;0m"; echo

	echo -n "Creating symlink..."
        cd /usr/local/bin && ln -sf ${BBINSTALL_PATH}/BashBurn.sh bashburn && cd ${BBINSTDIR}
	echo -e "\033[1;32m[DONE]\033[1;0m"; echo

	if [[ -e ${BBCONFFILE} ]]; then
		echo "Config file found! (${BBCONFFILE})"
		echo " Do you want to overwrite it? (y/n)"
		overwrite_selection
		echo; echo -n 'Installing config file...'
		cp -f ${BBROOTDIR}bashburnrc ${BBCONFFILE} 
		sed -e "s^BBROOTDIR.*BBROOTDIR: $BBINSTALL_PATH" -i ${BBCONFFILE}
		echo -e "\033[1;32m[DONE]\033[1;0m"
	else
		echo; echo -n "Installing config file..."
		cp -f ${BBROOTDIR}bashburnrc ${BBCONFFILE}
		sed -e "s^BBROOTDIR.*BBROOTDIR: $BBINSTALL_PATH" -i ${BBCONFFILE}
		echo -e "\033[1;32m[DONE]\033[1;0m"
	fi

	echo; echo "Do you want regular users to be able to"
	echo "change the global config file? (y/n)"
	echo "NOTE: On small systems (Say a computer you and your family uses)"
	echo " this might be a good idea."
	overwrite_selection
	echo; echo -n "Adjusting permissions on ${BBCONFFILE}..."
	chmod 666 ${BBCONFFILE}
	echo -e "\033[1;32m[DONE]\033[1;0m"; echo
	echo "Installation finished. Now start BashBurn with the"
	echo -e "command \033[1;36mbashburn\033[1;0m, and remember to"
	echo "configure it before trying to use it."
}


echo
echo "Installation script for BashBurn 1.3+"
echo

if whoami | grep root > /dev/null ; then
	
	echo "Where do you want to install BashBurn?"
	echo " (Default is /usr/local/BashBurn)"
	echo "Just press enter to use the default location."
	echo -n "Path: "
	read BBINSTALL_PATH
	if [[ "${BBINSTALL_PATH}" = "" ]]; then
		BBINSTALL_PATH="/usr/local/BashBurn"
		echo "Installing BashBurn into ${BBINSTALL_PATH}"
		sleep 1s
		install_files
	else
		install_files
	fi
else
	echo "You are not root."
	echo "Please run this script as root before starting BashBurn"
fi
